@@ -38,26 +38,25 @@ ac_table = {
                         '--parallel', '--uses-index', '--index-data-url', '--index-labels-url', '--index-batch-size',
                         '--uses-query', '--query-data-url', '--query-labels-url', '--query-batch-size', '--num-query',
                         '--top-k'],
-        'pod': ['--help', '--name', '--log-config', '--identity', '--log-id', '--port-ctrl', '--ctrl-with-ipc',
-                '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses', '--py-modules',
-                '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
+        'pod': ['--help', '--name', '--log-config', '--identity', '--log-id', '--show-exc-info', '--port-ctrl',
+                '--ctrl-with-ipc', '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses',
+                '--py-modules', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                 '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                 '--skip-on-error', '--num-part', '--uses-internal', '--entrypoint', '--pull-latest', '--volumes',
                 '--host', '--port-expose', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls',
-                '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id', '--pea-role',
-                '--uses-before', '--uses-after', '--parallel', '--shards', '--polling', '--scheduling',
-                '--remote-access', '--remote-type', '--pod-role'],
+                '--timeout-ready', '--env', '--expose-public', '--pea-id', '--pea-role', '--uses-before',
+                '--uses-after', '--parallel', '--shards', '--polling', '--scheduling', '--remote-access',
+                '--remote-type', '--pod-role'],
         'flow': ['--help', '--uses', '--logserver', '--logserver-config', '--log-id', '--optimize-level',
                  '--output-type', '--output-path', '--inspect'],
-        'gateway': ['--help', '--name', '--log-config', '--identity', '--log-id', '--port-ctrl', '--ctrl-with-ipc',
-                    '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses', '--py-modules',
-                    '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
+        'gateway': ['--help', '--name', '--log-config', '--identity', '--log-id', '--show-exc-info', '--port-ctrl',
+                    '--ctrl-with-ipc', '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses',
+                    '--py-modules', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                     '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                     '--skip-on-error', '--num-part', '--max-message-size', '--proxy', '--prefetch',
                     '--prefetch-on-recv', '--restful', '--rest-api', '--host', '--port-expose', '--daemon',
                     '--runtime-backend', '--runtime', '--runtime-cls', '--timeout-ready', '--env', '--expose-public',
-                    '--show-exc-info', '--pea-id', '--pea-role'],
-        'ping': ['--help', '--timeout', '--retries', '--print-response'],
+                    '--pea-id', '--pea-role'], 'ping': ['--help', '--timeout', '--retries', '--print-response'],
         'check': ['--help', '--summary-exec', '--summary-driver'],
         'hub login': ['--help', '--username', '--password', '--registry', '--repository'],
         'hub new': ['--help', '--output-dir', '--template', '--type', '--overwrite'],
@@ -66,18 +65,18 @@ ac_table = {
         'hub build': ['--help', '--username', '--password', '--registry', '--repository', '--pull', '--push',
                       '--dry-run', '--prune-images', '--raise-error', '--test-uses', '--test-level', '--timeout-ready',
                       '--host-info', '--daemon', '--no-overwrite'],
-        'hub push': ['--help', '--username', '--password', '--registry', '--repository'],
-        'hub pull': ['--help', '--username', '--password', '--registry', '--repository'],
+        'hub push': ['--help', '--username', '--password', '--registry', '--repository', '--no-overwrite'],
+        'hub pull': ['--help', '--username', '--password', '--registry', '--repository', '--no-overwrite'],
         'hub list': ['--help', '--username', '--password', '--registry', '--repository', '--name', '--kind',
                      '--keywords', '--type', '--local-only'],
         'hub': ['--help', 'login', 'new', 'init', 'create', 'build', 'push', 'pull', 'list'],
-        'pea': ['--help', '--name', '--log-config', '--identity', '--log-id', '--port-ctrl', '--ctrl-with-ipc',
-                '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses', '--py-modules',
-                '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
+        'pea': ['--help', '--name', '--log-config', '--identity', '--log-id', '--show-exc-info', '--port-ctrl',
+                '--ctrl-with-ipc', '--timeout-ctrl', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--uses',
+                '--py-modules', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in', '--socket-out',
                 '--max-socket-retries', '--dump-interval', '--read-only', '--separated-workspace', '--memory-hwm',
                 '--skip-on-error', '--num-part', '--uses-internal', '--entrypoint', '--pull-latest', '--volumes',
                 '--host', '--port-expose', '--daemon', '--runtime-backend', '--runtime', '--runtime-cls',
-                '--timeout-ready', '--env', '--expose-public', '--show-exc-info', '--pea-id', '--pea-role'],
+                '--timeout-ready', '--env', '--expose-public', '--pea-id', '--pea-role'],
         'log': ['--help', '--groupby-regex', '--refresh-time'],
         'client': ['--help', '--batch-size', '--mode', '--top-k', '--mime-type', '--continue-on-error',
                    '--return-results', '--max-message-size', '--proxy', '--prefetch', '--prefetch-on-recv', '--restful',
