@@ -16,7 +16,7 @@ class BasePod(ExitStack):
     Internally, the peas can run with the process/thread backend. They can be also run in their own containers
     """
 
-    def __init__(self, args: 'argparse.Namespace', needs: Set[str] = None):
+    def __init__(self, args: Union['argparse.Namespace', Dict], needs: Set[str] = None):
         """
 
         :param args: arguments parsed from the CLI
@@ -31,7 +31,12 @@ class BasePod(ExitStack):
         self.deducted_head = None
         self.deducted_tail = None
 
-        self.peas_args = self._parse_args(args)
+        if isinstance(args, Dict):
+            # This is used when a Pod is created in a remote context, where peas & their connections are already given.
+            self.peas_args = args
+        else:
+            self.peas_args = self._parse_args(args)
+
         for a in self.all_args:
             self._set_conditional_args(a)
 
