@@ -4,6 +4,7 @@ from contextlib import ExitStack
 from pathlib import Path
 from typing import Dict, Tuple, Set, List, Optional
 
+from ....jaml.helper import complete_path
 from ....enums import RemotePeapodType
 from ....importer import ImportExtensions
 from ....jaml import JAML
@@ -12,8 +13,9 @@ from ....logging import JinaLogger
 
 def _add_file_to_list(_file: str, _file_list: Set, logger: 'JinaLogger'):
     if _file and _file.endswith(('yml', 'yaml', 'py')):
-        if Path(_file).is_file():
-            _file_list.add(_file)
+        real_file = complete_path(_file)
+        if Path(real_file).is_file():
+            _file_list.add(real_file)
             logger.debug(f'adding file {_file} to be uploaded to remote context')
         else:
             logger.warning(f'file {_file} doesn\'t exist in the disk')
@@ -111,7 +113,7 @@ class JinadAPI:
             r = requests.get(url=self.alive_url, timeout=self.timeout)
             return r.status_code == requests.codes.ok
         except requests.exceptions.RequestException as ex:
-            self.logger.error(f'something wrong on remote: {repr(ex)}')
+            self.logger.error(f'something wrong on remote: {ex!r}')
             return False
 
     def upload(self, args: Dict, **kwargs) -> bool:
@@ -141,7 +143,7 @@ class JinadAPI:
                     self.logger.success(f'Got status {r.json()["status"]} from remote')
                     return True
             except requests.exceptions.RequestException as ex:
-                self.logger.error(f'something wrong on remote: {repr(ex)}')
+                self.logger.error(f'something wrong on remote: {ex!r}')
 
     def create(self, args: Dict, **kwargs) -> Optional[str]:
         """ Create a remote pea/pod
@@ -159,9 +161,9 @@ class JinadAPI:
                 return r.json()[f'{self.kind}_id']
             self.logger.error(f'couldn\'t create pod with remote jinad {r.json()}')
         except requests.exceptions.RequestException as ex:
-            self.logger.error(f'couldn\'t create pod with remote jinad {repr(ex)}')
+            self.logger.error(f'couldn\'t create pod with remote jinad {ex!r}')
 
-    async def logstream(self, remote_id: 'str'):
+    async def logstream(self, remote_id: 'str', log_id: 'str'):
         """ websocket log stream from remote pea/pod
         :param remote_id: the identity of that pea/pod
         :return:
@@ -190,8 +192,10 @@ class JinadAPI:
                             complete_log_message = log_line[current_line_number]
                             log_line_dict = json.loads(complete_log_message.split('\t')[-1].strip())
                             name = log_line_dict['name']
+
                             if name not in remote_loggers:
-                                remote_loggers[name] = JinaLogger(context=f'🌏 {name}')
+                                remote_loggers[name] = JinaLogger(context=f'🌏 {name}', log_id=log_id)
+
                             # TODO(Deepankar): change logging level, process name in local logger
                             remote_loggers[name].info(f'{log_line_dict["message"].strip()}')
                         except json.decoder.JSONDecodeError:
@@ -199,7 +203,7 @@ class JinadAPI:
         except websockets.exceptions.ConnectionClosedOK:
             self.logger.error(f'🌏 Client got disconnected from server')
         except websockets.exceptions.WebSocketException as e:
-            self.logger.error(f'🌏 Got following error while streaming logs via websocket {repr(e)}')
+            self.logger.error(f'🌏 Got following error while streaming logs via websocket {e!r}')
         except asyncio.CancelledError:
             self.logger.info(f'🌏 Logging task cancelled successfully')
         finally:
@@ -222,7 +226,7 @@ class JinadAPI:
             r = requests.delete(url=url, timeout=self.timeout)
             return r.status_code == requests.codes.ok
         except requests.exceptions.RequestException as ex:
-            self.logger.error(f'couldn\'t connect with remote jinad url {repr(ex)}')
+            self.logger.error(f'couldn\'t connect with remote jinad url {ex!r}')
             return False
 
 
